@@ -57,6 +57,15 @@ def get_wf_json(code=13):
     return d
 
 
+def humid():
+    """
+    Open Metroから東京の直近の湿度を取得して返す
+    """
+    url = "https://api.open-meteo.com/v1/forecast?latitude=35.6785&longitude=139.6823&hourly=relativehumidity_2m"
+    resp = requests.get(url)
+    d = loads(resp.text)
+    return d['hourly']['relativehumidity_2m'][0]
+
 
 def rp(code=13):
     """
